@@ -168,15 +168,6 @@ demand_load! {
 mod tests {
     use super::*;
 
-    #[test]
-    fn test_message() {
-        let code = Error::fast_error(HRESULT::from_win32(0));
-        assert_eq!(code.message(), "The operation completed successfully.");
-
-        let code = Error::fast_error(HRESULT::from_win32(997));
-        assert_eq!(code.message(), "Overlapped I/O operation is in progress.");
-    }
-
     #[test]
     fn win32_error_conversion() {
         let code = Error::fast_error(HRESULT::from_win32(18));
